==> charcoal-0.7.0.zip: charcoal-0.7.0/charcoal/classes/core/SQLCriteria.class.php <==
<?php
/**
* SQL說饹
*
* PHP version 5
*
* @package    components.db
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
class SQLCriteria
{
	var $_where;
	var $_params;
	var $_order_by;
	var $_limit;
	var $_offset;

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct( $where = NULL, $params = NULL, $order_by = NULL, $limit = NULL, $offset = NULL )
	{
		$this->_where     = $where;
		$this->_params    = $params;
		$this->_order_by  = $order_by;
		$this->_limit     = $limit;
		$this->_offset    = $offset;
	}

	/*
	 * WHERE
	 */
	public function getWhereClause()
	{
		return $this->_where;
	}

	/*
	 * WHERE
	 */
	public function setWhereClause( $where )
	{
		$this->_where = $where;
	}

	/*
	 * ѥ᡼
	 */
	public function getParams()
	{
		return $this->_params;
	}

	/*
	 * ѥ᡼
	 */
	public function setParams( $params )
	{
		$this->_params = $params;
	}

	/*
	 * ORDER BY
	 */
	public function getOrderBy()
	{
		return $this->_order_by;
	}

	/*
	 * ORDER BY
	 */
	public function setOrderBy( $order_by )
	{
		$this->_order_by = $order_by;
	}

	/*
	 * LIMIT
	 */
	public function getLimit()
	{
		return $this->_limit;
	}

	/*
	 * LIMIT
	 */
	public function setLimit( $limit )
	{
		$this->_limit = $limit;
	}

	/*
	 * OFFSET
	 */
	public function getOffset()
	{
		return $this->_offset;
	}

	/*
	 * OFFSET
	 */
	public function setOffset( $offset )
	{
		$this->_offset = $offset;
	}

	/*
	 * ʸ
	 */
	public function __toString()
	{
		$str  = "[SQLCondition: ";
		$str .= "where=" . $this->_where;
		$str .= "params=" . $this->_params;
		$str .= "order_by=" . $this->_order_by;
		$str .= "limit=" . $this->_limit;
		$str .= "offset=" . $this->_offset;
		$str .= "]";

		return $str;
	}
}
return __FILE__;

==> charcoal-0.10.0.zip: charcoal-0.10.0/charcoal/classes/core/SQLCriteria.class.php <==
<?php
/**
* SQL說饹
*
* PHP version 5
*
* @package    components.db
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
class SQLCriteria
{
	var $_where;
	var $_params;
	var $_order_by;
	var $_limit;
	var $_offset;

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct( String $where = NULL, Vector $params = NULL, String $order_by = NULL, Integer $limit = NULL, Integer $offset = NULL )
	{
		$this->_where     = $where;
		$this->_params    = $params;
		$this->_order_by  = $order_by;
		$this->_limit     = $limit;
		$this->_offset    = $offset;
	}

	/*
	 * WHERE
	 */
	public function getWhereClause()
	{
		return $this->_where;
	}

	/*
	 * WHERE
	 */
	public function setWhereClause( String $where )
	{
		$this->_where = $where;
	}

	/*
	 * ѥ᡼
	 */
	public function getParams()
	{
		return $this->_params;
	}

	/*
	 * ѥ᡼
	 */
	public function setParams( Vector $params )
	{
		$this->_params = $params;
	}

	/*
	 * ORDER BY
	 */
	public function getOrderBy()
	{
		return $this->_order_by;
	}

	/*
	 * ORDER BY
	 */
	public function setOrderBy( String $order_by )
	{
		$this->_order_by = $order_by;
	}

	/*
	 * LIMIT
	 */
	public function getLimit()
	{
		return $this->_limit;
	}

	/*
	 * LIMIT
	 */
	public function setLimit( Integer $limit )
	{
		$this->_limit = $limit;
	}

	/*
	 * OFFSET
	 */
	public function getOffset()
	{
		return $this->_offset;
	}

	/*
	 * OFFSET
	 */
	public function setOffset( Integer $offset )
	{
		$this->_offset = $offset;
	}

	/*
	 * ʸ
	 */
	public function __toString()
	{
		$str  = "[SQLCondition: ";
		$str .= "where=" . $this->_where;
		$str .= "params=" . $this->_params;
		$str .= "order_by=" . $this->_order_by;
		$str .= "limit=" . $this->_limit;
		$str .= "offset=" . $this->_offset;
		$str .= "]";

		return $str;
	}
}
return __FILE__;
